@@ -9,7 +9,7 @@ This is the main entry point - import this module to use the Configuration Manag
 """
 
 from .lifecycle import start, stop
-from .data import CONFIG_MANAGER, ConfigRPC, ConfigSpec
+from .data import CONFIG_MANAGER, CONFIG_SUP, ConfigRPC, ConfigSpec
 from .sources import FileSource, EnvironmentSource, RuntimeSource
 from .client import Config
 
@@ -21,6 +21,7 @@ __all__ = [
     "FileSource",
     "EnvironmentSource", 
     "RuntimeSource",
+    "CONFIG_SUP",
     "CONFIG_MANAGER",
     "ConfigRPC"
 ]
